# Table of Contents

- [synchronizing-process-variants](<./synchronizing-process-variants.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Synchronizing Process Variants](<./Synchronizing-Process-Variants.md>)
  - [Introduction](<./Synchronizing-Process-Variants/Introduction.md>)
  - [Prerequisites](<./Synchronizing-Process-Variants/Prerequisites.md>)
  - [Enabling Process Variants Import](<./Synchronizing-Process-Variants/Enabling-Process-Variants-Import.md>)
  - [Aggregation of Process Template and Variants](<./Synchronizing-Process-Variants/Aggregation-of-Process-Template-and-Variants.md>)
  - [Synchronizing Application and Organizational Fact Sheets](<./Synchronizing-Process-Variants/Synchronizing-Application-and-Organizational-Fact-Sheets.md>)
  - [Visualizing Relations](<./Synchronizing-Process-Variants/Visualizing-Relations.md>)
  - [Synchronizing Other Fact Sheets](<./Synchronizing-Process-Variants/Synchronizing-Other-Fact-Sheets.md>)
  - [Synchronizing Hierarchy and Process Relations](<./Synchronizing-Process-Variants/Synchronizing-Hierarchy-and-Process-Relations.md>)
  - [Handling of Process Variant Dimensions](<./Synchronizing-Process-Variants/Handling-of-Process-Variant-Dimensions.md>)
